arb: Arbitrary-precision floating-point ball arithmetic
=======================================================

Description
-----------

Arb is a C library for arbitrary-precision floating-point ball
arithmetic, developed by Fredrik Johansson
(fredrik.johansson@gmail.com). It supports efficient high-precision
computation with polynomials, power series, matrices and special
functions over the real and complex numbers, with automatic, rigorous
error control.

License
-------

GNU General Public License v2+


Upstream Contact
----------------

 - Fredrik Johansson: fredrik.johansson@gmail.com

 - https://arblib.org/

 - http://github.com/fredrik-johansson/arb/

Dependencies
------------

-  FLINT
-  MPIR or GMP
-  MPFR


Special Update/Build Instructions
---------------------------------
